summaryrefslogtreecommitdiffstats
path: root/chrome/browser/memory_details.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/memory_details.cc')
-rw-r--r--chrome/browser/memory_details.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/chrome/browser/memory_details.cc b/chrome/browser/memory_details.cc
index ccf279e..fdf6231 100644
--- a/chrome/browser/memory_details.cc
+++ b/chrome/browser/memory_details.cc
@@ -232,7 +232,7 @@ void MemoryDetails::CollectChildInfoOnUIThread() {
title = L"Untitled";
process.titles.push_back(title);
// We need to check the pending entry as well as the virtual_url to
// see if it's an about:memory URL (we don't want to count these in the
// total memory usage of the browser).
//
@@ -248,10 +248,10 @@ void MemoryDetails::CollectChildInfoOnUIThread() {
const NavigationEntry* last_committed_entry =
contents->controller().GetLastCommittedEntry();
if ((last_committed_entry &&
- LowerCaseEqualsASCII(last_committed_entry->virtual_url().spec(),
+ LowerCaseEqualsASCII(last_committed_entry->display_url().spec(),
chrome::kAboutMemoryURL)) ||
(pending_entry &&
- LowerCaseEqualsASCII(pending_entry->virtual_url().spec(),
+ LowerCaseEqualsASCII(pending_entry->display_url().spec(),
chrome::kAboutMemoryURL)))
process.is_diagnostics = true;
}
@@ -232,7 +232,7 @@ void MemoryDetails::CollectChildInfoOnUIThread() {
title = L"Untitled";
process.titles.push_back(title);
- // We need to check the pending entry as well as the virtual_url to
+ // We need to check the pending entry as well as the display_url to
// see if it's an about:memory URL (we don't want to count these in the
// total memory usage of the browser).